@@ -544,7 +544,7 @@ if (is.null(cstr$Gammat)){
   nbparGamma = Lt*(Lt+1)/2  
 }
 
-theta$nbpar = (K-1) + K*(D*L + D + Lt + nbparSigma + nbparGamma)
+theta$nbpar = (in_K-1) + in_K*(D*L + D + Lt + nbparSigma + nbparGamma)
 
 return(theta)
 }
\ No newline at end of file
